/*!
 * @license
 * Copyright 2016 Alfresco Software, Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { async, TestBed } from '@angular/core/testing';
import { AppConfigService, CoreModule } from '@alfresco/adf-core';
import { DiagramsService } from './diagrams.service';

declare let jasmine: any;

describe('DiagramsService', () => {

    let service: DiagramsService;

    beforeEach(async(() => {
        TestBed.configureTestingModule({
            imports: [
                CoreModule
            ],
            providers: [
                DiagramsService
            ]
        }).compileComponents();
    }));

    beforeEach(() => {
        let appConfig: AppConfigService = TestBed.get(AppConfigService);
        appConfig.config.ecmHost = 'http://localhost:9876/ecm';

        service = TestBed.get(DiagramsService);
    });

    beforeEach(() => {
        jasmine.Ajax.install();
    });

    afterEach(() => {
        jasmine.Ajax.uninstall();
    });

    it('getProcessDefinitionModel should perform a call against the server', (done) => {
        service.getProcessDefinitionModel('fake-processDefinitionId').subscribe(() => {
            done();
        });

        jasmine.Ajax.requests.mostRecent().respondWith({
            status: 200
        });
    });

    it('getRunningProcessDefinitionModel should perform a call against the server', (done) => {
        service.getRunningProcessDefinitionModel('fake-processInstanceId').subscribe(() => {
            done();
        });

        jasmine.Ajax.requests.mostRecent().respondWith({
            status: 200
        });
    });

    it('getTagsByNodeId catch errors call', (done) => {
        service.getProcessDefinitionModel('fake-processDefinitionId').subscribe(() => {
        }, () => {
            done();
        });

        jasmine.Ajax.requests.mostRecent().respondWith({
            status: 403
        });
    });
});
